==> estateplat-common-1.2.3-20180105.063451-5-sources.jar: cn/gtmap/estateplat/model/commodityHouse/projectManage/FcjyXjspfLjz.java <==
package cn.gtmap.estateplat.model.commodityHouse.projectManage;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-12-12
 * @description 新建商品逻辑幢表
 */
@Table(name = "fcjy_xjspf_ljz")
public class FcjyXjspfLjz {
    @Id
    private String ljzid;//逻辑幢ID
    private String ljzh;//逻辑幢号
    private String zrzh;//逻辑幢号
    private String lszd;//隶属宗地
    private String zldz;//坐落地址
    private Integer fwcs;//房屋层数
    private String xmid;//项目ID(关联开发项目)
    private String xkid;//预售许可ID(关联预售许可)
    private String jsydsyqid;//建设用地使用权ID(关联建设用地使用权)
    private String jsgcghxkzid;//建设工程规划许可证ID(关联建设工程规划许可证)
    private String jzgcsgxkzid;//建筑工程施工许可证ID(关联建筑工程施工许可证)
    private Date sbjgjdqssj;//申报价格阶段起始时间
    private Date sbjgjdjssj;//申报价格阶段结束时间

    public String getLjzid() {
        return ljzid;
    }

    public void setLjzid(String ljzid) {
        this.ljzid = ljzid;
    }

    public String getLjzh() {
        return ljzh;
    }

    public void setLjzh(String ljzh) {
        this.ljzh = ljzh;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getLszd() {
        return lszd;
    }

    public void setLszd(String lszd) {
        this.lszd = lszd;
    }

    public String getZldz() {
        return zldz;
    }

    public void setZldz(String zldz) {
        this.zldz = zldz;
    }

    public Integer getFwcs() {
        return fwcs;
    }

    public void setFwcs(Integer fwcs) {
        this.fwcs = fwcs;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getXkid() {
        return xkid;
    }

    public void setXkid(String xkid) {
        this.xkid = xkid;
    }

    public String getJsydsyqid() {
        return jsydsyqid;
    }

    public void setJsydsyqid(String jsydsyqid) {
        this.jsydsyqid = jsydsyqid;
    }

    public String getJsgcghxkzid() {
        return jsgcghxkzid;
    }

    public void setJsgcghxkzid(String jsgcghxkzid) {
        this.jsgcghxkzid = jsgcghxkzid;
    }

    public String getJzgcsgxkzid() {
        return jzgcsgxkzid;
    }

    public void setJzgcsgxkzid(String jzgcsgxkzid) {
        this.jzgcsgxkzid = jzgcsgxkzid;
    }

    public Date getSbjgjdqssj() {
        return sbjgjdqssj;
    }

    public void setSbjgjdqssj(Date sbjgjdqssj) {
        this.sbjgjdqssj = sbjgjdqssj;
    }

    public Date getSbjgjdjssj() {
        return sbjgjdjssj;
    }

    public void setSbjgjdjssj(Date sbjgjdjssj) {
        this.sbjgjdjssj = sbjgjdjssj;
    }
}

==> estateplat-common-1.2.3-20180316.075059-46-sources.jar: cn/gtmap/estateplat/model/commodityHouse/projectManage/FcjyXjspfLjz.java <==
package cn.gtmap.estateplat.model.commodityHouse.projectManage;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-12-12
 * @description 新建商品逻辑幢表
 */
@Table(name = "fcjy_xjspf_ljz")
public class FcjyXjspfLjz {
    @Id
    private String ljzid;//逻辑幢ID
    private String ljzh;//逻辑幢号
    private String zrzh;//逻辑幢号
    private String lszd;//隶属宗地
    private String zldz;//坐落地址
    private Integer fwcs;//房屋层数
    private String xmid;//项目ID(关联开发项目)
    private String xkid;//预售许可ID(关联预售许可)
    private String jsydsyqid;//建设用地使用权ID(关联建设用地使用权)
    private String jsgcghxkzid;//建设工程规划许可证ID(关联建设工程规划许可证)
    private String jzgcsgxkzid;//建筑工程施工许可证ID(关联建筑工程施工许可证)
    private Date sbjgjdqssj;//申报价格阶段起始时间
    private Date sbjgjdjssj;//申报价格阶段结束时间
    private String ysc;//（YC：预测 SC：实测 ）

    public String getLjzid() {
        return ljzid;
    }

    public void setLjzid(String ljzid) {
        this.ljzid = ljzid;
    }

    public String getLjzh() {
        return ljzh;
    }

    public void setLjzh(String ljzh) {
        this.ljzh = ljzh;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getLszd() {
        return lszd;
    }

    public void setLszd(String lszd) {
        this.lszd = lszd;
    }

    public String getZldz() {
        return zldz;
    }

    public void setZldz(String zldz) {
        this.zldz = zldz;
    }

    public Integer getFwcs() {
        return fwcs;
    }

    public void setFwcs(Integer fwcs) {
        this.fwcs = fwcs;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getXkid() {
        return xkid;
    }

    public void setXkid(String xkid) {
        this.xkid = xkid;
    }

    public String getJsydsyqid() {
        return jsydsyqid;
    }

    public void setJsydsyqid(String jsydsyqid) {
        this.jsydsyqid = jsydsyqid;
    }

    public String getJsgcghxkzid() {
        return jsgcghxkzid;
    }

    public void setJsgcghxkzid(String jsgcghxkzid) {
        this.jsgcghxkzid = jsgcghxkzid;
    }

    public String getJzgcsgxkzid() {
        return jzgcsgxkzid;
    }

    public void setJzgcsgxkzid(String jzgcsgxkzid) {
        this.jzgcsgxkzid = jzgcsgxkzid;
    }

    public Date getSbjgjdqssj() {
        return sbjgjdqssj;
    }

    public void setSbjgjdqssj(Date sbjgjdqssj) {
        this.sbjgjdqssj = sbjgjdqssj;
    }

    public Date getSbjgjdjssj() {
        return sbjgjdjssj;
    }

    public void setSbjgjdjssj(Date sbjgjdjssj) {
        this.sbjgjdjssj = sbjgjdjssj;
    }

    public String getYsc() {
        return ysc;
    }

    public void setYsc(String ysc) {
        this.ysc = ysc;
    }
}
